/**
 * @file
 * This file holds the master view for the layout js app.
 */
(function ($, _, Backbone, Drupal) {

  "use strict";

  // @todo: be RESTful. Not sure whether the router/rest.module are in place.
  // Instead of using REST verbs, POST will be used and $_POST['_method'] will
  // contain the verb.
  Backbone.emulateHTTP = true;
  // Payloads will be sent as application/x-www-form-urlencoded, in
  // $_POST['model'].
  Backbone.emulateJSON = true;

  Drupal.layout = Drupal.layout || {};
  Drupal.layout.AppView = Backbone.View.extend({
    initialize: function(options) {
      this.regionsView = new Drupal.layout.RegionsView({
        collection: this.model.get('regions'),
        el: this.$el.find('.layout-display')
      });
      this.settings = options.settings;
    },
    render: function() {
      // @todo: this should move to layout.admin.js and provide better handling.
      // Do not setup the js app if another user is currently operating on this
      // layout (locked on the server via TempStore).
      if (this.settings.locked) {
        return false;
      }
      this.regionsView.render();
      this.$el.sortable({
        items: '.block',
        connectWith: '.connected-sortable',
        cursor: 'move',
        stop: function(event, ui) {
          ui.item.trigger('drop', ui.item.index());
        }
      });
      return this;
    },
    remove: function() {
      this.$el.sortable('destroy');
      this.regionsView.remove();
      this.$el.remove();
    }
  });

})(jQuery, _, Backbone, Drupal);
