/**
 * @file
 * This view controls a region and the blockInstances contained in it. Opens
 * the BlockSelectorModalView on request.
 */
(function ($, _, Backbone, Drupal) {

  "use strict";

  Drupal.layout = Drupal.layout || {};

  Drupal.layout.RegionView = Backbone.View.extend({
    events:{
      'click .plus-icon':'onClickAdd',
      'click .gear-icon':'onClickConfigure',
      'reorder':'reorderInstances'
    },

    onClickConfigure:function (e) {
      this.dialogView = new Drupal.layout.RegionModalView({
        model: this.model,
        title: this.model.get('label')
      });
      this.dialogView.render();
    },

    onClickAdd:function (e) {
      var collection = Drupal.layout.getBlocksCollection();
      this.modalView = new Drupal.layout.BlockSelectorModalView({
        model: this.model,
        collection: collection,
        title: Drupal.t('Please select a block to place in the regions %region', {'%region': this.model.get('label')})
      });
      this.modalView.render();
      e.preventDefault();
      e.stopPropagation();
      return ;
    },

    // @todo: listen to collection events in app-view.js instead/propagate event.
    saveFullLayout: function() {
      // Show the "changed" notice.
      $('.display-changed').removeClass('js-hide');
      Drupal.layout.appModel.save();
    },

    initialize:function () {
      var blockInstances = this.model.get('blockInstances');
      this._collectionView = new Drupal.layout.UpdatingCollectionView({
        collection:blockInstances,
        nestedViewConstructor:Drupal.layout.BlockInstanceView,
        nestedViewTagName:'div'
      });

      // @todo: be selective about what change-events trigger requests to the
      // server.
      // "Debounce" rapid sequences of change events to avoid unnecessary requests.
      blockInstances.on('change', _.debounce(function() {
        this.saveFullLayout();
      }, 100), this);
      blockInstances.on('add', this.saveFullLayout, this);
      blockInstances.on('remove', this.saveFullLayout, this);
    },

    render:function () {
      this.$el.html(Drupal.theme.layoutRegion(this.model.get('id'), this.model.get('label')));
      this._collectionView.setElement(this.$el.find('.region-blocks'));
      this._collectionView.render();
      return this;
    },

    remove:function () {
      this.$el.empty();
      this._collectionView.remove();
    },

    reorderInstances:function (event, model, position) {
      var collection = this.model.get('blockInstances');
      // handle cross collection.
      if (!collection.contains(model)) {
        // let's remove it from the other first before adding it here.
        model.collection.remove(model);
      } else {
        if (model.get('weight')==position) {
          return ;
        }
        collection.remove(model);
      }
      collection.each(function (model, index) {
        var weight = index;
        if (index >= position) {
          weight += 1;
        }
        model.set('weight', weight);
      });
      model.set('weight', position);
      collection.add(model, {at:position});
      collection.trigger('reorder');
      this.render();
    }
  });

})(jQuery, _, Backbone, Drupal);
