/**
 * @file
 */
(function ($, _, Backbone, Drupal) {
  "use strict";

  Drupal.layout = Drupal.layout || {};

  Drupal.layout.UpdatingCollectionView = Backbone.View.extend({
    initialize:function (options) {
      if (!options.nestedViewConstructor) {
        throw "no child view constructor provided";
      }
      if (!options.nestedViewTagName) {
        throw "no child view tag name provided";
      }

      this._nestedViewConstructor = options.nestedViewConstructor;
      this._nestedViewTagName = options.nestedViewTagName;

      this._nestedViews = [];

      this.collection.each(this.addModel, this);

      this.collection.bind('add', this.addModel, this);
      this.collection.bind('remove', this.removeModel, this);
    },

    _getViewByModel: function(model) {
      // @todo this probably should be cached/tracked.
      var vs = _(this._nestedViews).select(function (nv) {
        return nv.model === model;
      });
      return vs.length ? vs[0] : false;
    },

    addModel:function (model) {
      var nv = new this._nestedViewConstructor({
        tagName:this._nestedViewTagName,
        model:model
      });

      this._nestedViews.push(nv);
      if (this._rendered) {
        this.$el.append(nv.render().$el);
      }
    },

    removeModel:function (model) {
      var viewToRemove = this._getViewByModel(model);
      this._nestedViews = _(this._nestedViews).without(viewToRemove);
      if (this._rendered) {
        viewToRemove.$el.remove();
      }
    },

    render:function () {
      this._rendered = true;
      this.$el.empty();
      // Use the collection to make sure the order of the rendered views is
      // up-to-date.
      this.collection.each(function(m) {
        var nv = this._getViewByModel(m);
        this.$el.append(nv.render().$el);
      }, this);
      return this;
    }
  });

})(jQuery, _, Backbone, Drupal);
