<?php

/**
 * @file
 * Definition of Drupal\page\PageFormController.
 */

namespace Drupal\page;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityFormController;
use Drupal\page\Plugin\Core\Entity\Page;

/**
 * Form controller for the page edit/add forms.
 */
class PageFormController extends EntityFormController {

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::form().
   */
  public function form(array $form, array &$form_state, EntityInterface $page) {
    $form['label'] = array(
      '#type' => 'textfield',
      '#title' => t('Page title'),
      '#maxlength' => 255,
      '#default_value' => $page->label(),
      '#description' => t("Example: 'Latest news' or 'About us'."),
      '#required' => TRUE,
    );
    $form['id'] = array(
      '#type' => 'machine_name',
      '#default_value' => $page->id(),
      '#machine_name' => array(
        'exists' => 'page_load',
        'source' => array('label'),
      ),
      '#disabled' => !$page->isNew(),
    );
    $form['path'] = array(
      '#type' => 'textfield',
      '#title' => t('Page path'),
      '#default_value' => $page->path,
      '#size' => 40,
      '#field_prefix' => url(NULL, array('absolute' => TRUE)),
    );

    // Get list of layouts and expose that for page layout selection.
    $layouts = drupal_container()->get('plugin.manager.layout')->getDefinitions();
    $layout_options = array();
    foreach ($layouts as $key => $layout) {
      $layout_options[$key] = $layout['title'];
    }
    $form['layout'] = array(
      '#type' => 'select',
      '#title' => t('Layout'),
      '#default_value' => isset($page->layout) ? $page->layout : '',
      '#options' => $layout_options,
    );

    return parent::form($form, $form_state, $page);
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::actions().
   */
  protected function actions(array $form, array &$form_state) {
    // Only includes a Save action for the entity, no direct Delete button.
    return array(
      'submit' => array(
        '#value' => t('Save'),
        '#validate' => array(
          array($this, 'validate'),
        ),
        '#submit' => array(
          array($this, 'submit'),
          array($this, 'save'),
        ),
      ),
    );
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::save().
   */
  public function save(array $form, array &$form_state) {
    $page = $this->getEntity($form_state);
    $page->save();
    menu_router_rebuild();

    watchdog('page', 'Landing page @label saved.', array('@label' => $page->label()), WATCHDOG_NOTICE);
    drupal_set_message(t('Landing page %label saved.', array('%label' => $page->label())));

    $form_state['redirect'] = 'admin/content/pages';
  }

}

