<?php

/**
 * @file
 * Definition of Drupal\page\Plugin\Core\Entity\Page.
 */

namespace Drupal\page\Plugin\Core\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\Core\Annotation\Plugin;
use Drupal\Core\Annotation\Translation;


/**
 * Defines the page entity class.
 *
 * @Plugin(
 *   id = "page",
 *   label = @Translation("Page"),
 *   module = "page",
 *   controller_class =  "Drupal\Core\Config\Entity\ConfigStorageController",
 *   form_controller_class = {
 *     "default" = "Drupal\page\PageFormController",
 *   },
 *   list_controller_class = "Drupal\page\PageListController",
 *   list_path = "admin/content/pages",
 *   uri_callback = "page_uri",
 *   config_prefix = "page.page",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *   }
 * )
 */
class Page extends ConfigEntityBase {

  /**
   * The page ID (machine name).
   *
   * @var string
   */
  public $id;

  /**
   * The page UUID.
   *
   * @var string
   */
  public $uuid;

  /**
   * The page title.
   *
   * @var string
   */
  public $label;

  /**
   * Path associated with this page.
   *
   * @var string
   */
  public $path;

  /**
   * Layout machine name associated with this page.
   *
   * @var string
   */
  public $layout;

}
