<?php

/**
 * @file
 * Administration functions to maintain a set of pages using layouts.
 */

use Drupal\page\Plugin\Core\Entity\Page;

/**
 * Page callback: Presents list of landing pages.
 *
 * @see page_menu()
 */
function page_page_list() {
  $controller = entity_list_controller('page');
  return $controller->render();
}

/**
 * Page callback: Presents the page editing form.
 *
 * @see page_menu()
 */
function page_page_edit(Page $page) {
  drupal_set_title(t('<em>Edit landing page</em> @label', array('@label' => $page->label())), PASS_THROUGH);
  return entity_get_form($page);
}

/**
 * Page callback: Provides the new page addition form.
 *
 * @see page_menu()
 */
function page_page_add() {
  $page = entity_create('page', array());
  return entity_get_form($page);
}

/**
 * Page callback: Form constructor for page deletion confirmation form.
 *
 * @see page_menu()
 */
function page_confirm_delete($form, &$form_state, Page $page) {
  // Always provide entity id in the same form key as in the entity edit form.
  $form['id'] = array('#type' => 'value', '#value' => $page->id());
  $form_state['page'] = $page;
  return confirm_form($form,
    t('Are you sure you want to remove the landing page %title?', array('%title' => $page->label())),
    'admin/content/pages',
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * Form submission handler for page_confirm_delete().
 */
function page_confirm_delete_submit($form, &$form_state) {
  $page = $form_state['page'];
  $page->delete();
  drupal_set_message(t('Landing page %label has been deleted.', array('%label' => $page->label())));
  watchdog('page', 'Landing page %label has been deleted.', array('%label' => $page->label()), WATCHDOG_NOTICE);
  $form_state['redirect'] = 'admin/content/pages';
}
